@@ -2,7 +2,7 @@
  *
  * User-related functions on UN*X
  *
- * $Id: unix_user.c,v 1.13 2000/05/06 11:17:44 nisse Exp $
+ * $Id: unix_user.c,v 1.14 2000/05/08 20:17:26 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -41,6 +41,7 @@
 #if HAVE_UNISTD_H
 #include <unistd.h>
 #endif
+
 #include <signal.h>
 
 #if HAVE_CRYPT_H
@@ -65,6 +66,10 @@
 # struct utmp;
 #endif
 
+#if HAVE_LIBUTIL_H
+# include <libutil.h>
+#endif
+
 #include "unix_user.c.x"
 
 
@@ -146,7 +151,12 @@ lsh_make_utmp(struct lsh_user *user,
   struct utmp *log;
   NEW_SPACE(log);
 
+#if HAVE_UT_NAME
   CP(log->ut_name, user->name);
+#elif HAVE_UT_USER
+  CP(log->ut_user, user->name);
+#endif
+  
   CP_TTY(log->ut_line, ttyname);
 
 #if HAVE_UT_HOST
